/****************************************************************************/
/*! \file		matlab.c
	\brief		Visualization in MatLab
	\author		Iliya Voronov, http://powerdsp.narod.ru
	\version	1.2
  
  Visualisation in MatLab:
  plot drowing, eye diagram, constellation diagram
*/
/*****************************************************************************/

#ifndef _MATLAB_H_
#define _MATLAB_H_

#define _MATLAB_VIS_ 1

//! Open MATLAB
/*!	Open MATLAB and create arrays and plots for plotArr function. 
	Should be called before all other functions.
	\param	updInt		plot update interval
*/
extern void openMatlab( int updInt );

//! Plot array
/*!	Plot real array with plot command.
	All arrays are plotter in the same window, 
	up to 4 arrays can be plotted simultaneously.
	Array are identifieds by its name, if no array with specified name
	exists, empty channel is allocated for the array.
	New samples are put to circular buffer of 512 samples, then 
	whole buffer is plotted.
	To plot 10 complex samples from array arr use 2 following commands
	plotArr( "arr_re", &arr[0].re, 10, 2 );
	plotArr( "arr-im", &arr[0].im, 10, 2 );
	\param	pName		name of array
	\param	pArr		poiner to array of 16-bit samples
	\param	len			number of plotted samples
	\param	step		step from sample to semple in pArr array
*/
extern void plotArr(	const char	  * pName,	const short	  * pArr,
						unsigned short	len,	unsigned short	step	);

//! Plot eye diagram
/*! Plot eye diagram of 4 complex samples per symbol
	New 4 complex samples are put to circular buffer of 17 samples, then
	whole buffer is plotted.
	\param	pCarr		pointer to array of 16-bit samples, format [0].re, [0].im, [1].re ... [3].im
*/
extern void eyeDiag4(	const short	  * pCarr );

//! Plot constellation diagram
/*! Plot constellation diagram
	New complex sample is put to circular buffer of 17 samples, then
	whole buffer is plotted. 
	The newest samples are show with red color, oldest - with blue.
	\param	pComp		pointer to array of 16-bit samples, format re, im
*/
extern void constDiag(	const short	  * pComp );


//! Close MATLAB
/*!	Close MATLAB. Currently this function just update plot and 
	do not close MATLAB 
*/
extern void closeMatlab();



#endif //_MATLAB_H_
